/*
 * file Task.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM
 *
 * (c) Copyright IBM Corporation 2004, 2008.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */

package javax.wvcm;

import javax.wvcm.PropertyNameList.PropertyName;
import javax.wvcm.WvcmException.ReasonCode;

/**
 * A proxy for a task resource.
 * 
 * A task resource provides the motivation for the logical change performed by an activity.
 * A variety of terms are used in various systems for a task, including change request,
 * modification request, change order, and workitem.
 * 
 * @since 1.0
 */
public interface Task extends Resource {

    /**
     * Create a new persistent task, where the provider can allocate the location for the
     * new task.
     * The provider should use the client-specified location if it is valid,
     * but can select a different location if the location is not valid
     * or already identifies a task.
     * <p>
     * Postconditions:
     * <li>(initialize-resource): A new task resource exists at the location of this Resource.
     * 
     * @param feedback Specifies optional feedback to the caller.
     * @return A proxy for this new resource, whose properties are specified by feedback.
     * @throws WvcmException ReasonCode:
     * <li>{@link ReasonCode#CANNOT_CREATE_AT_THIS_LOCATION}:
     *  If the location of this Task does not identify a repository that supports
     *  the creation of tasks, the request MUST fail.
     */
    public Task doCreateGeneratedResource(Feedback feedback) throws WvcmException;

    /**
     * The activities that are performing this task.
     * This is the inverse of the {@link Activity#TASK_LIST} property.
     */
    public static final PropertyName<ResourceList<Activity>> ACTIVITY_LIST =
        new PropertyName<ResourceList<Activity>>("activity-list"); //$NON-NLS-1$

    /**
     * Get the {@link #ACTIVITY_LIST} property.
     * 
     * @return the {@link #ACTIVITY_LIST} property.
     * @throws WvcmException if this Task was not created with
     * {@link #ACTIVITY_LIST} as a wanted property.
     */
    public ResourceList<Activity> getActivityList() throws WvcmException;

}
